@@ -452,3 +452,29 @@ def rolling_window_view(array, window_shape=(0,), axis=None, writeable=False):
     return np.lib.stride_tricks.as_strided(
         array, shape=new_shape, strides=new_strides, writeable=writeable
     )
+
+
+def window_lin_reg(x, y, w):
+    '''From https://stackoverflow.com/questions/70296498/efficient-computation-of-moving-linear-regression-with-numpy-numba/70304475#70304475'''
+    sx = sliding_window_view(x, w, axis=0).sum(axis=-1)
+    sy = sliding_window_view(y, w, axis=0).sum(axis=-1)
+    sx2 = sliding_window_view(x**2, w, axis=0).sum(axis=-1)
+    sxy = sliding_window_view(x * y, w, axis=0).sum(axis=-1)
+    slope = (w * sxy - sx * sy) / (w * sx2 - sx**2)
+    intercept = (sy - slope * sx) / w
+    return slope, intercept
+
+
+def window_sum_nan_mean(x, w, axis=0):
+    return np.nanmean(sliding_window_view(x, w, axis=axis), axis=-1)
+
+
+def window_lin_reg_mean(x, y, w):
+    '''From https://stackoverflow.com/questions/70296498/efficient-computation-of-moving-linear-regression-with-numpy-numba/70304475#70304475'''
+    sx = window_sum_nan_mean(x, w)
+    sy = window_sum_nan_mean(y, w)
+    sx2 = window_sum_nan_mean(x**2, w)
+    sxy = window_sum_nan_mean(x * y, w)
+    slope = (sxy - sx * sy) / (sx2 - sx**2)
+    intercept = sy - slope * sx
+    return slope, intercept
